@@ -2,13 +2,12 @@ from pathlib import Path
 import importlib.metadata
 import re
 
-from hyperlink import URL
-from sphinx.ext.intersphinx import resolve_reference_in_inventory
+from yarl import URL
 
 DOCS = Path(__file__).parent
 
-GITHUB = URL.from_text("https://github.com/")
-HOMEPAGE = GITHUB.child("python-jsonschema", "referencing")
+GITHUB = URL("https://github.com/")
+HOMEPAGE = GITHUB / "python-jsonschema/referencing"
 
 project = "referencing"
 author = "Julian Berman"
@@ -39,7 +38,6 @@ pygments_style = "lovelace"
 pygments_dark_style = "one-dark"
 
 html_theme = "furo"
-html_static_path = []
 
 # See sphinx-doc/sphinx#10785
 _TYPE_ALIASES = dict(
@@ -53,18 +51,6 @@ def _resolve_broken_refs(app, env, node, contnode):
     if node["refdomain"] != "py":
         return
 
-    # Evade tobgu/pyrsistent#267
-    if node["reftarget"].startswith("pyrsistent.typing."):
-        node["reftarget"] = node["reftarget"].replace(".typing.", ".")
-        return resolve_reference_in_inventory(
-            env, "pyrsistent", node, contnode
-        )
-    elif node["reftarget"] == "PList":
-        node["reftarget"] = "pyrsistent.PList"
-        return resolve_reference_in_inventory(
-            env, "pyrsistent", node, contnode
-        )
-
     kind, target = _TYPE_ALIASES.get(node["reftarget"], (None, None))
     if kind is not None:
         return app.env.get_domain("py").resolve_xref(
@@ -105,8 +91,8 @@ intersphinx_mapping = {
 # -- Options for extlinks extension ------------------------------------------
 
 extlinks = {
-    "gh": (str(HOMEPAGE.child("%s")), None),
-    "github": (str(GITHUB.child("%s")), None),
+    "gh": (str(HOMEPAGE) + "/%s", None),
+    "github": (str(GITHUB) + "/%s", None),
 }
 
 # -- Options for the linkcheck builder ---------------------------------------
@@ -120,8 +106,8 @@ linkcheck_ignore = [
     entire_domain("codecov.io"),
     entire_domain("img.shields.io"),
     f"{GITHUB}.*#.*",
-    str(HOMEPAGE.child("actions")),
-    str(HOMEPAGE.child("python-jsonschema/workflows/CI/badge.svg")),
+    str(HOMEPAGE / "actions"),
+    str(HOMEPAGE / "python-jsonschema/workflows/CI/badge.svg"),
 ]
 
 # -- Options for spelling extension ------------------------------------------
